#include "functions.hpp"

// open dialog
createDialog "Dlg";
waitUntil {dialog};

// get dialog controls
_display = findDisplay 20000;
_ctrlHeader = _display displayCtrl 20000;
_ctrlHeaderBack = _display displayCtrl 20010;
_ctrlGroupList = _display displayCtrl 20001;
_ctrlAnimList = _display displayCtrl 20002;
_ctrlConnectFrom = _display displayCtrl 20003;
_ctrlConnectTo = _display displayCtrl 20004;
_ctrlFilter = _display displayCtrl 20005;


// populate the filter list
{
	if (!("complex" in toLower (_x select 0)) || !(isNull AV_object2)) then {
		_idx = _ctrlFilter lbAdd (_x select 0);
	};
}forEach FILTERTYPES;
_ctrlFilter lbSetCurSel 0;


// put the unit info in the header
_dName = getText(configFile>>"CfgVehicles">>typeOf AV_object>>"displayName");
_AIinfo = format["%1<br>Unit class: %2<br>Animations config: %3",_dName,typeOf AV_object,AV_AnimConfigs];
_ctrlHeader ctrlSetText _AIinfo;


// list the available animation groups
[] call _listGroups;


// list all available animations
[] call _listAnims;


// keep checking for button presses, or selection changes, while the dialog is open
doit = 0;	
sleep 1;
_abort = false;
_lastGroup = 0;
_lastidx = -1;
_group = "";
_complexAnim = "";
_complexPos = [];
_complexDir = 0;

while {dialog && !_abort} do {
	
	// if the selected base class has changed, update the listed animations
	_idxGroup = lbcursel _ctrlGroupList;
	if (_idxGroup!=_lastGroup) then {
		_lastGroup = _idxGroup;
		_group = _ctrlGroupList lbText _idxGroup;
		// list anims of selected group
		[] call _listAnims;
		// reset AI attachment
		[_group,""] call _attachAI;
		
	};
	
	// get the selected animation
	_idxAnim = lbcursel _ctrlAnimList;
	_anim = _ctrlAnimList lbText _idxAnim;
	_ctrlAnimList ctrlSetToolTip _anim;
	
	// if the selected animation has changed, update the "Connect From/To" fields
	if (_idxAnim!=_lastidx) then {
		_animConfig = configFile>>AV_AnimConfigs>>"States">>_anim;
		// update the "ConnectFrom/To" fields
		lbClear _ctrlConnectFrom;
		_connectFrom = getArray (_animConfig>>"connectFrom");
		if (count _connectFrom!=0) then {
			{
				if (typeName _x=="string") then {
					_ctrlConnectFrom lbAdd _x;
				};
			}forEach _connectFrom;
			lbSort _ctrlConnectFrom;
			_ctrlConnectFrom lbSetCurSel 0;
		};
		lbClear _ctrlConnectTo;
		_connectTo = getArray (_animConfig>>"connectTo");
		if (count _connectTo!=0) then {
			{
				if (typeName _x=="string") then {
					_ctrlConnectTo lbAdd _x;
				};
			}forEach _connectTo;
			lbSort _ctrlConnectTo;
			_ctrlConnectTo lbSetCurSel 0;
		};
		// find the base class for the animation
		_group = [_anim] call _findGroup;
		// get some animation properties, and display them in the header field
		if (_lastidx!=-1) then {
			_looped = getNumber(_animConfig>>"looped");
			_terminal = getNumber(_animConfig>>"terminal");
			_objects = getArray(_animConfig>>"objects");
			_animInfo = format["%1<br>looped: %2, terminal: %3, group: %4",_anim,_looped,_terminal,_group];
			_complexAnim = getText(_animConfig>>"complexAnimConnectTo");
			if (_complexAnim!="") then {
				_complexPos = getArray(_animConfig>>"secondaryPos");
				_complexDir = getNumber(_animConfig>>"secondaryDir");
				_animInfo = format["%1<br>complexAnimConnectTo: %2, pos: %3, dir: %4",_animInfo,_complexAnim,_complexPos,_complexDir];
			};
			[true] call _toggleInfoBox;
			_ctrlHeader ctrlSetText _animInfo;
		};		
		_lastidx = _idxAnim;
	};
	
	// a button was pressed (or the filter selection changed)
	if (doit!=0) then {
		AV_LastAnim = _anim;

		// reset AIs position and direction (in case the last animation moved him away)
		if (AV_object distance (AV_orgpos select 0)>1) then {
			AV_object setPos (AV_orgpos select 0);
		};
		AV_object setDir (AV_orgpos select 1);
		sleep .1;

		// respond to the button presses
		switch (doit) do {
			case 1: {
				// attach AI to a fixed object, if we're playing a crew animation
				[_group,_anim] call _attachAI;
				// if it's a complex animation, animate 2nd AI as well
				if ((_complexAnim!="") && !(isNull AV_object2)) then {
					AV_object2 setPos (AV_object modelToWorld _complexPos);
					AV_object2 setDir  (getDir AV_object + _complexDir);
					(group AV_object2) setFormDir  (getDir AV_object + _complexDir);
					AV_object2 playMove _complexAnim;
				};
				AV_object playMove _anim;
			};
			case 2: {
				// attach AI to a fixed object, if we're playing a crew animation
				[_group,_anim] call _attachAI;
				AV_object switchMove _anim;
			};
			// filter list
			case 3: {
				[] call _listAnims;
			};
			// reset to default animation
			case 4: {
				["",""] call _attachAI;
				AV_object switchMove AV_defAnim;
				[false] call _toggleInfoBox;
				_ctrlHeader ctrlSetText _AIinfo;
			};
			// select the "ConnectFrom" animation in the main listbox
			case 10: {
				_connFrom = _ctrlConnectFrom lbText (lbCurSel _ctrlConnectFrom);
				_group = [_connFrom,_group] call _selAnim;
			};
			// select the "ConnectTo" animation in the main listbox
			case 11: {
				_connTo = _ctrlConnectTo lbText (lbCurSel _ctrlConnectTo);
				_group = [_connTo,_group] call _selAnim;
			};
		};
		doit = 0;
	};
	sleep .1;
};
