#include "\vbs2\headers\function_library.hpp"
#include "defines.hpp"


// list all available base classes, plus and entry for "All" and a catch-all one for smaller groups "(Other)"
_listGroups = {
	_ctrlGroupList lbAdd "* All *";
	if (count AV_AnimClasses>1) then {
		{
			_idx = _ctrlGroupList lbAdd _x;
		}forEach AV_AnimClasses;
		lbSort _ctrlGroupList;
		_ctrlGroupList lbAdd "(Other)";
	};
	_ctrlGroupList lbSetCurSel 0;
};


// select the specified animation in the main listbox
_selectAnim = {
	private ["_anim","_defidx"];
	_anim = _this select 0;
	_defidx = 0;
	for "_i" from 0 to (lbSize _ctrlAnimList)-1 do {
		if (_ctrlAnimList lbtext _i==_anim) exitWith {
			_defidx = _i;
		};
	};
	_ctrlAnimList lbSetCurSel _defidx;
};

// reset the group selection to * All *, and select specified animation
_selAnim = {
	private ["_anim","_group"];
	_anim = _this select 0;
	_group = _this select 1;
	if (_anim!="") then {
		AV_LastAnim = _anim;
		if (_group!="* All *") then {
			_group = "* All *";
			_ctrlGroupList lbSetCurSel 0;
			[] call _listAnims;
		} else {
			[AV_LastAnim] call _selectAnim;
		};
	};
	_group
};


// function to list the animations that are available for the selected group
_listAnims = {
	private ["_groupSel","_group","_show","_defidx"];
	lbClear _ctrlAnimList;
	// check which group is selected
	_groupSel = _ctrlGroupList lbText (lbCurSel _ctrlGroupList);
	// go through the list of all animations
	{
		// find the group for each animation
		_group = _x select 1;
		// if it's not in the listed groups, then put it into "Other"
		if !(_group in AV_AnimClasses) then {
			_group = "(Other)";
		};
		// if the group matches the selected one, or we want to see all, then add animation to the list
		if ((_groupSel=="* All *") || (_groupSel==_group)) then {
			_ctrlAnimList lbAdd (_x select 0);
		};
	}forEach AV_Animations;
	// sort the list
	lbSort _ctrlAnimList;
	
	// apply any filters
	[] call _filterList;

	// select the previously used animation
	[AV_LastAnim] call _selectAnim;
};


// find the base class for the selected animations
_findGroup = {
	private ["_anim","_group"];
	_anim = _this select 0;
	{	
		if (_anim==_x select 0) exitWith {
			_group = _x select 1;
		};
	}forEach AV_Animations;
	_group
};


// change the size of the top info section, depending on whether an animation is selected or not
_toggleInfoBox = {
	private ["_show","_pos"];
	_show = _this select 0;
	{
		_pos = ctrlPosition _x;
		_width = _pos select 2;
		if (_show) then {
			if (_width<.4) then {
				_width = _width+.65;
			};
		} else {
			if (_width>.4) then {
				_width = _width-.65;
			};
		};
		_pos set [2,_width];
		_x ctrlSetPosition _pos;
		_x ctrlCommit .1;
	}forEach [_ctrlHeader,_ctrlHeaderBack];
};


// attach or detach the AI to a fixed object (needed for crew animations)
_attachAI = {
	private ["_group","_anim","_attach","_pos"];
	_group = _this select 0;
	_anim = toLower(_this select 1);
	_attach = ((_group=="Crew") || ("kia_" in _anim));
	
	if (_attach) then {
		AV_attachObj disableGeo [false,true,true,true];
		if !(isAttached AV_object) then {
			AV_object attachTo [AV_attachObj,[0,0,0]];
		};
	} else {
		if (isAttached AV_object) then {
			detach AV_object;
			AV_attachObj disableGeo [true,true,true,true];
			AV_object setDir (AV_orgpos select 1);
		};
	};
};


// remove animation that don't match the specified filter
_filterList = {
	private ["_filterType","_filterArray","_baton","_filter"];			
	_filterType = lbCurSel _ctrlFilter;
	_filterArray = [];
	
	// "Filter Weapon"
	if ((_filterType==1) || (_filterType==3)) then {
		// remove animations with these name parts 
		// (unless the AI owns that respective weapon, in which case we remove it from that array)
		_filterArray = (FILTERTYPES select 1) select 1;
		if (count weapons AV_object>0) then {
			if (pistolWeapon AV_object!="") then {
				_filterArray = _filterArray - ["wpst"];
			};
			if (secondaryWeapon AV_object!="") then {
				_filterArray = _filterArray - ["wlnr"];
			};
			if (primaryWeapon AV_object!="") then {
				_baton = [configFile>>"CfgWeapons",primaryWeapon AV_object,"vbs2_baton_base"] call fn_vbs_isKindOf;
				if (_baton) then {
					_filterArray = _filterArray - ["wbtn"];
				} else {
					_filterArray = _filterArray - ["wrfl"];
				};
			};
			{
				if (getNumber (configFile>>"CfgWeapons">>_x>>"useAsBinocular")==1) then {
					_filterArray = _filterArray - ["wbin"];
				};
			}forEach (weapons AV_object);
		} else {
			_filterArray = _filterArray - ["wnon"];
		};
	};
	
	// "Filter Stance"
	if ((_filterType==2) || (_filterType==3)) then {
		{
			if !(_x in animationState AV_object) then {
				_filterArray = _filterArray + [_x];
			};
		}forEach ((FILTERTYPES select 2) select 1);
	};
	
	// "Filter Complex"
	if (_filterType==4) then {
		_filterArray = _filterArray + ((FILTERTYPES select 4) select 1);
	};

	// go through the animation list, and remove all matching entries
	if (count _filterArray!=0) then {
		if (count _filterArray!=0) then {
			for [{_i=(lbSize _ctrlAnimList)-1},{_i>=0},{_i=_i-1}] do {
				{
					_filter = _x;
					// if the filter is preceded by an exclamation mark, remove entries that don't match the string
					if ("!" in _filter) then {
						_filter = trim[_filter,1,0];
						if !(_filter in (toLower (_ctrlAnimList lbText _i))) then {
							_ctrlAnimList lbDelete _i;
						};
					// if no "!" prefix, remove entries that DO match the string
					} else {
						if (_filter in (toLower (_ctrlAnimList lbText _i))) then {
							_ctrlAnimList lbDelete _i;
						};
					};
				}forEach _filterArray;
			};
		};
	};
	
};