#include "\vbs2\headers\function_library.hpp"

// find the AI unit to animate
_AIs = allUnits - [player];
if (count _AIs==0) exitWith {
	warningMessage "An AI unit of the type to be animated should exist in the mission.";
};
AV_object = _AIs select 0;
AV_object2 = objNull;
if (count _AIs>1) then {
	AV_object2 = _AIs select 1;
};
AV_orgpos = [getPos AV_object,getDir AV_object];
AV_object allowDammage false;
AV_defAnim = animationState AV_object;

// point the player towards the AI
player setDir ([player, getpos AV_object] call fn_vbs_dirTo);

// which config are the unit's animations defined in?
// for adults it's "CfgMovesMaleSdr", for children and animals it's "CfgMovesChildSdr", "CfgMovesCamel", "CfgMovesCow", "CfgMovesPastor", "CfgMovesdonkey" or "CfgMovesGoat"
AV_AnimConfigs = getText (configFile>>"CfgVehicles">>typeOf AV_object>>"moves");

// find possible animation base classes
// e.g. for "CfgMovesMaleSdr": ["AmovPknlMstpSrasWlnrDnon","Crew","DefaultDie","StandBase","TransAnimBase","(Other)"]
AV_AnimClasses  = [];

// function to find the highest possible parent class for an animation
_findParent = {
	private ["_entry","_parent"];
	_entry = _this select 0;
	_parent = _entry;
	while {(configName (inheritsFrom _parent)!="Default") && (configName (inheritsFrom _parent)!="")} do {
		_parent = inheritsFrom _parent;
	};	
	configName _parent
};

// read and save the available animations
AV_Animations = [];
_parents = [];
_children = [];
_states = (configFile>>AV_AnimConfigs>>"States");
for "_i" from 0 to (count _states)-1 do {
	_anim = _states select _i;
	// get the highest parent class for this animation
	_parent = [_anim] call _findParent;
	// check if we have it indexed already
	_parentIdx = _parents find _parent;
	// if not, then add it to the list
	if (_parentIdx==-1) then {
		_parents = _parents + [_parent];
		_children = _children + [1];
	} else {
	// if it does exist already, increase its count
		_children set [_parentIdx,(_children select _parentIdx)+1];
	};
	AV_Animations = AV_Animations + [[configName _anim,_parent]];
};
AV_LastAnim = "";


// only use parent classes that have a minimum number of children	
for "_i" from 0 to (count _parents)-1 do {
	if (_children select _i>50) then {
		AV_AnimClasses = AV_AnimClasses + [_parents select _i];
	};
};


// attachment object to use for crew animations
if (isNil "AV_attachObj") then {
	// for version 1.50+ use the 10cm ball, for older versions use the 9v battery
	_attachType = "vbs2_visual_sphere_10cm";
	_version = call compile format["%1.%2",versionNumber select 0,versionNumber select 1];
	if (_version<1.5) then {
		_attachType = "vbs2_battery_9v";
	};
	// place it a bit higher, as otherwise some animations may end up underground
	_pos = AV_object modelToWorld [0,0,1];
	AV_attachObj = _attachType createVehicle _pos;
	AV_attachObj setPos _pos;
	// hide it, when not in use
	AV_attachObj disableGeo [true,true,true,true];
};			


player addAction["Show Animations","anim.sqf"];


// constantly show the current animation in the upper right corner
titleRsc["HUD", "PLAIN"]; 
waitUntil {!isNull AV_HUD};
_ctrl = AV_HUD displayCtrl 20001;
while {true} do {
	_ctrl ctrlSetStructuredText parseText format["<t align='right' shadow='true' size='1.6'>%1</t>",animationState AV_object];
	sleep .1;
};


